from unittest.mock import Mock
from typing import Dict, Text, Any

import pytest
from _pytest.monkeypatch import MonkeyPatch
from sanic.testing import SanicTestClient

from rasax.community import metrics

TELEMETRY_URL = "/api/telemetry"


async def test_send_event(
    test_client: SanicTestClient,
    auth_header: Dict[Text, Text],
    monkeypatch: MonkeyPatch,
):
    track = Mock()
    monkeypatch.setattr(metrics, "track", track)

    data = {"event_name": "Test Event", "properties": {"foo": "bar"}}

    response = await test_client.post(TELEMETRY_URL, json=data, headers=auth_header)

    assert response.status == 204
    track.assert_called_once_with("Test Event", {"foo": "bar"}, None)


@pytest.mark.parametrize(
    "body",
    [
        {},
        {"event_name": "foo", "properties": {}},
        {"event_name": "foo", "properties": {}, "context": {}},
    ],
)
async def test_invalid_request(
    test_client: SanicTestClient, auth_header: Dict[Text, Text], body: Dict[Text, Any],
):
    response = await test_client.post(TELEMETRY_URL, json=body, headers=auth_header)
    assert response.status == 400
